# quetzal-openapi-client
Quetzal: an API to manage data files and their associated metadata.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.3.0
- Package version: 0.3.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://quetz.al](https://quetz.al)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/quetz-al/quetzal-openapi-client.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/quetz-al/quetzal-openapi-client.git`)

Then import the package:
```python
import quetzal.openapi_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import quetzal.openapi_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import quetzal.openapi_client
from quetzal.openapi_client.rest import ApiException
from pprint import pprint

configuration = quetzal.openapi_client.Configuration()
# Configure HTTP basic authorization: basic
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = quetzal.openapi_client.AuthenticationApi(quetzal.openapi_client.ApiClient(configuration))

try:
    # Login.
    api_response = api_instance.auth_get_token()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AuthenticationApi->auth_get_token: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.quetz.al/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthenticationApi* | [**auth_get_token**](docs/AuthenticationApi.md#auth_get_token) | **POST** /auth/token | Login.
*AuthenticationApi* | [**auth_logout**](docs/AuthenticationApi.md#auth_logout) | **POST** /auth/logout | Logout.
*DataApi* | [**public_file_details**](docs/DataApi.md#public_file_details) | **GET** /data/files/{uuid} | Fetch public file.
*DataApi* | [**public_file_fetch**](docs/DataApi.md#public_file_fetch) | **GET** /data/files/ | List public files.
*DataApi* | [**public_query_create**](docs/DataApi.md#public_query_create) | **POST** /data/queries/ | Prepare a query.
*DataApi* | [**public_query_details**](docs/DataApi.md#public_query_details) | **GET** /data/queries/{qid} | Query details.
*DataApi* | [**public_query_fetch**](docs/DataApi.md#public_query_fetch) | **GET** /data/queries/ | List public queries.
*DataApi* | [**workspace_commit**](docs/DataApi.md#workspace_commit) | **PUT** /data/workspaces/{wid}/commit | Commit workspace.
*DataApi* | [**workspace_create**](docs/DataApi.md#workspace_create) | **POST** /data/workspaces/ | Create workspace.
*DataApi* | [**workspace_delete**](docs/DataApi.md#workspace_delete) | **DELETE** /data/workspaces/{wid} | Delete workspace.
*DataApi* | [**workspace_details**](docs/DataApi.md#workspace_details) | **GET** /data/workspaces/{wid} | Workspace details.
*DataApi* | [**workspace_fetch**](docs/DataApi.md#workspace_fetch) | **GET** /data/workspaces/ | List workspaces.
*DataApi* | [**workspace_file_create**](docs/DataApi.md#workspace_file_create) | **POST** /data/workspaces/{wid}/files/ | Upload file.
*DataApi* | [**workspace_file_delete**](docs/DataApi.md#workspace_file_delete) | **DELETE** /data/workspaces/{wid}/files/{uuid} | Delete a file.
*DataApi* | [**workspace_file_details**](docs/DataApi.md#workspace_file_details) | **GET** /data/workspaces/{wid}/files/{uuid} | Fetch file.
*DataApi* | [**workspace_file_fetch**](docs/DataApi.md#workspace_file_fetch) | **GET** /data/workspaces/{wid}/files/ | List files.
*DataApi* | [**workspace_file_set_metadata**](docs/DataApi.md#workspace_file_set_metadata) | **PUT** /data/workspaces/{wid}/files/{uuid} | Rewrite metadata.
*DataApi* | [**workspace_file_update_metadata**](docs/DataApi.md#workspace_file_update_metadata) | **PATCH** /data/workspaces/{wid}/files/{uuid} | Modify metadata.
*DataApi* | [**workspace_query_create**](docs/DataApi.md#workspace_query_create) | **POST** /data/workspaces/{wid}/queries/ | Prepare a query.
*DataApi* | [**workspace_query_details**](docs/DataApi.md#workspace_query_details) | **GET** /data/workspaces/{wid}/queries/{qid} | Query details.
*DataApi* | [**workspace_query_fetch**](docs/DataApi.md#workspace_query_fetch) | **GET** /data/workspaces/{wid}/queries/ | List queries.
*DataApi* | [**workspace_scan**](docs/DataApi.md#workspace_scan) | **PUT** /data/workspaces/{wid}/scan | Update views.
*PublicApi* | [**public_file_details**](docs/PublicApi.md#public_file_details) | **GET** /data/files/{uuid} | Fetch public file.
*PublicApi* | [**public_file_fetch**](docs/PublicApi.md#public_file_fetch) | **GET** /data/files/ | List public files.
*PublicApi* | [**public_query_create**](docs/PublicApi.md#public_query_create) | **POST** /data/queries/ | Prepare a query.
*PublicApi* | [**public_query_fetch**](docs/PublicApi.md#public_query_fetch) | **GET** /data/queries/ | List public queries.
*PublicApi* | [**workspace_create**](docs/PublicApi.md#workspace_create) | **POST** /data/workspaces/ | Create workspace.
*PublicApi* | [**workspace_fetch**](docs/PublicApi.md#workspace_fetch) | **GET** /data/workspaces/ | List workspaces.
*QueryApi* | [**public_query_create**](docs/QueryApi.md#public_query_create) | **POST** /data/queries/ | Prepare a query.
*QueryApi* | [**public_query_details**](docs/QueryApi.md#public_query_details) | **GET** /data/queries/{qid} | Query details.
*QueryApi* | [**public_query_fetch**](docs/QueryApi.md#public_query_fetch) | **GET** /data/queries/ | List public queries.
*QueryApi* | [**workspace_query_create**](docs/QueryApi.md#workspace_query_create) | **POST** /data/workspaces/{wid}/queries/ | Prepare a query.
*QueryApi* | [**workspace_query_details**](docs/QueryApi.md#workspace_query_details) | **GET** /data/workspaces/{wid}/queries/{qid} | Query details.
*QueryApi* | [**workspace_query_fetch**](docs/QueryApi.md#workspace_query_fetch) | **GET** /data/workspaces/{wid}/queries/ | List queries.
*WorkspaceApi* | [**public_query_details**](docs/WorkspaceApi.md#public_query_details) | **GET** /data/queries/{qid} | Query details.
*WorkspaceApi* | [**workspace_commit**](docs/WorkspaceApi.md#workspace_commit) | **PUT** /data/workspaces/{wid}/commit | Commit workspace.
*WorkspaceApi* | [**workspace_details**](docs/WorkspaceApi.md#workspace_details) | **GET** /data/workspaces/{wid} | Workspace details.
*WorkspaceApi* | [**workspace_fetch**](docs/WorkspaceApi.md#workspace_fetch) | **GET** /data/workspaces/ | List workspaces.
*WorkspaceApi* | [**workspace_file_create**](docs/WorkspaceApi.md#workspace_file_create) | **POST** /data/workspaces/{wid}/files/ | Upload file.
*WorkspaceApi* | [**workspace_file_delete**](docs/WorkspaceApi.md#workspace_file_delete) | **DELETE** /data/workspaces/{wid}/files/{uuid} | Delete a file.
*WorkspaceApi* | [**workspace_file_details**](docs/WorkspaceApi.md#workspace_file_details) | **GET** /data/workspaces/{wid}/files/{uuid} | Fetch file.
*WorkspaceApi* | [**workspace_file_fetch**](docs/WorkspaceApi.md#workspace_file_fetch) | **GET** /data/workspaces/{wid}/files/ | List files.
*WorkspaceApi* | [**workspace_file_set_metadata**](docs/WorkspaceApi.md#workspace_file_set_metadata) | **PUT** /data/workspaces/{wid}/files/{uuid} | Rewrite metadata.
*WorkspaceApi* | [**workspace_file_update_metadata**](docs/WorkspaceApi.md#workspace_file_update_metadata) | **PATCH** /data/workspaces/{wid}/files/{uuid} | Modify metadata.
*WorkspaceApi* | [**workspace_query_create**](docs/WorkspaceApi.md#workspace_query_create) | **POST** /data/workspaces/{wid}/queries/ | Prepare a query.
*WorkspaceApi* | [**workspace_query_details**](docs/WorkspaceApi.md#workspace_query_details) | **GET** /data/workspaces/{wid}/queries/{qid} | Query details.
*WorkspaceApi* | [**workspace_query_fetch**](docs/WorkspaceApi.md#workspace_query_fetch) | **GET** /data/workspaces/{wid}/queries/ | List queries.
*WorkspaceApi* | [**workspace_scan**](docs/WorkspaceApi.md#workspace_scan) | **PUT** /data/workspaces/{wid}/scan | Update views.


## Documentation For Models

 - [BaseMetadata](docs/BaseMetadata.md)
 - [Error](docs/Error.md)
 - [FileContents](docs/FileContents.md)
 - [MetadataByFamily](docs/MetadataByFamily.md)
 - [PaginatedFiles](docs/PaginatedFiles.md)
 - [PaginatedQueries](docs/PaginatedQueries.md)
 - [PaginatedWorkspaces](docs/PaginatedWorkspaces.md)
 - [PaginationEnvelope](docs/PaginationEnvelope.md)
 - [Query](docs/Query.md)
 - [QueryNoResults](docs/QueryNoResults.md)
 - [Token](docs/Token.md)
 - [Workspace](docs/Workspace.md)


## Documentation For Authorization


## basic

- **Type**: HTTP basic authentication


## bearer

- **Type**: Bearer authentication


## Author

support@quetz.al


